@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "clojure-ts-mode" "20251202.1521"
+(define-package "clojure-ts-mode" "20260220.715"
   "Major mode for Clojure code."
   '((emacs "30.1"))
-  :url "http://github.com/clojure-emacs/clojure-ts-mode"
-  :commit "96fdffcbe9e1b8ebf9ad14e23b06f62cc3422e22"
-  :revdesc "96fdffcbe9e1"
+  :url "https://github.com/clojure-emacs/clojure-ts-mode"
+  :commit "2831a50faa1a779128af3fa87f29d6e91f1d26b5"
+  :revdesc "2831a50faa1a"
   :keywords '("languages" "clojure" "clojurescript" "lisp")
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
